# coding=utf-8
import os, io, sys, asyncio, requests, arrow, json, time
# import astmain as __


# coding=utf-8
import os, io, sys, asyncio, requests, arrow, json, time
# import astmain as __
import astmain_py777.astmain as __
from astmain_py777.astmain import print
__.print_hook = True
print = __.print

print("111                 :", 111)
print("111                 :", 111)
print("111                 :", 222)
